@@ -83,6 +83,14 @@ class ShellTest(utils.TestCase):
         self.run_command(command)
         self.assert_called('GET', '/volumes/detail?group_id=fake_id')
 
+    @mock.patch("cinderclient.utils.print_list")
+    def test_list_duplicate_fields(self, mock_print):
+        self.run_command('list --field Status,id,Size,status')
+        self.assert_called('GET', '/volumes/detail')
+        key_list = ['ID', 'Status', 'Size']
+        mock_print.assert_called_once_with(mock.ANY, key_list,
+            exclude_unavailable=True, sortby_index=0)
+
     def test_list_availability_zone(self):
         self.run_command('availability-zone-list')
         self.assert_called('GET', '/os-availability-zone')
@@ -385,8 +393,13 @@ class ShellTest(utils.TestCase):
         self.run_command('--os-volume-api-version 3.5 message-list --marker=1')
         self.assert_called('GET', '/messages?marker=1')
 
+    def test_list_with_image_metadata_before_3_4(self):
+        self.assertRaises(exceptions.UnsupportedAttribute,
+                          self.run_command,
+                          'list --image_metadata image_name=1234')
+
     def test_list_filter_image_metadata(self):
-        self.run_command('--os-volume-api-version 3.0 '
+        self.run_command('--os-volume-api-version 3.4 '
                          'list --image_metadata image_name=1234')
         url = ('/volumes/detail?%s' %
                parse.urlencode([('glance_metadata', {"image_name": "1234"})]))
